@@ -17,14 +17,7 @@ DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
 FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 """
 
-###############################################################################
-#                                                                             #
-# Apr 2022                                                                    #
-# felix@kemeth.de                                                             #
-#                                                                             #
-###############################################################################
-
-from configparser import ConfigParser
+from configparser import SectionProxy
 from typing import Tuple
 
 import numpy as np
@@ -40,22 +33,19 @@ class Model:
 
     Includes functions to train and validate network.
 
-    Arguments:
-    dataloader_train          - Dataloader with training data
-    dataloader_val            - Dataloader with validation or test data
-    network                   - PyTorch module with the network topology
-    config                    - Config with hyperparameters
-    path                      - Path where the model should be saved
+    Args:
+        dataloader_train: Dataloader with training data
+        dataloader_val: Dataloader with validation or test data
+        network: PyTorch module with the network topology
+        config: Config with hyperparameters
     """
 
     def __init__(self,
                  dataloader_train: DataLoader,
                  dataloader_val: DataLoader,
                  network: torch.nn.Module,
-                 config: ConfigParser,
-                 path: str = ''):
+                 config: SectionProxy):
         super().__init__()
-        self.base_path = path
 
         self.dataloader_train = dataloader_train
         self.dataloader_val = dataloader_val
@@ -66,40 +56,32 @@ class Model:
             self.boundary_conditions = None
 
         self.net = network
-        self.device = self.net.device
-        print('Using:', self.device)
-        self.net = self.net.to(self.device)
+        print('Using:', self.net.device)
+        self.net = self.net.to(self.net.device)
 
-        self.learning_rate = float(config['lr'])
-        self.weight_decay = float(config['weight_decay'])
-
-        self.criterion = torch.nn.MSELoss(reduction='sum').to(self.device)
+        self.criterion = torch.nn.MSELoss(reduction='sum').to(self.net.device)
 
         self.optimizer = torch.optim.Adam(
             self.net.parameters(),
-            lr=self.learning_rate,
-            weight_decay=self.weight_decay)
+            lr=config.getfloat('lr'),
+            weight_decay=config.getfloat('weight_decay'))
 
         self.scheduler = torch.optim.lr_scheduler.ReduceLROnPlateau(
-            self.optimizer, patience=int(config['patience']),
-            factor=float(config['reduce_factor']), min_lr=1e-7)
+            self.optimizer,
+            patience=config.getint('patience'),
+            factor=config.getfloat('reduce_factor'),
+            min_lr=1e-7)
 
     def pad(self, data: torch.Tensor, target: torch.Tensor) -> Tuple:
         """
         Pad input/target depending on boundary conditions and kernel size.
 
-        Arguments
-        -------
-        data: torch tensor
-            Tensor containing the X data.
-        target: torch tensor
-            Tensor containing the Y data.
+        Args:
+            data: Tensor containing the X data.
+            target: Tensor containing the Y data.
 
-        Returns
-        -------
-        data: torch tensor
+        Returns:
             Padded tensor containing the X data.
-        target: torch tensor
             Padded tensor containing the Y data.
         """
         if self.boundary_conditions == 'periodic':
@@ -116,9 +98,8 @@ class Model:
         """
         Train model over one epoch.
 
-        Returns
-        -------
-        Loss averaged over the training data
+        Returns:
+            Loss averaged over the training data
         """
         self.net = self.net.train()
 
@@ -128,7 +109,7 @@ class Model:
             self.optimizer.zero_grad()
 
             # move batch to device
-            batch = [tensor.to(self.device) for tensor in batch]
+            batch = [tensor.to(self.net.device) for tensor in batch]
 
             # forward
             data, target = batch[0], batch[2]
@@ -157,9 +138,8 @@ class Model:
 
         Updates best accuracy.
 
-        Returns
-        -------
-        Loss averaged over the validation data
+        Returns:
+            Loss averaged over the validation data
         """
         self.net = self.net.eval()
 
@@ -167,7 +147,7 @@ class Model:
         with torch.no_grad():
             for batch in self.dataloader_val:
                 # move batch to device
-                batch = [tensor.to(self.device) for tensor in batch]
+                batch = [tensor.to(self.net.device) for tensor in batch]
 
                 # forward
                 data, target = batch[0], batch[2]
@@ -185,49 +165,41 @@ class Model:
 
         return sum_loss / cnt
 
-    def save_network(self, name: str) -> str:
+    def save_network(self, model_file_name: str) -> str:
         """
         Save model to disk.
 
-        Arguments
-        -------
-        name         - Model filename.
+        Args:
+            model_file_name: Model filename.
 
-        Returns
-        -------
-        Model filename.
+        Returns:
+            Model filename.
         """
-        model_file_name = self.base_path+name
         torch.save(self.net.state_dict(), model_file_name)
-        return name
+        return model_file_name
 
-    def load_network(self, name: str) -> None:
+    def load_network(self, model_file_name: str) -> None:
         """
         Load model from disk.
 
-        Arguments
-        -------
-        name         - Model filename.
+        Args:
+            model_file_name: Model filename.
         """
-        model_file_name = self.base_path+name
         self.net.load_state_dict(torch.load(model_file_name))
 
-    def dfdt(self, time: float, input_array: np.ndarray, delta_x: float) -> np.ndarray:
+    def dfdt(self,
+             time: float,  # pylint: disable=unused-argument
+             input_array: np.ndarray,
+             delta_x: float) -> np.ndarray:
         """
-        Return learned du/dt of the model.
+        Return du/dt of the model.
 
-        Arguments
-        -------
-        t: float
-            Time step.
-        y: numpy array of shape(N*n_vars)
-            Input snapshot.
-        delta_x: float
-            Delta x of spatial grid.
+        Args:
+            t: Time step.
+            input_array: Input snapshot.
+            delta_x: Delta x of spatial grid.
 
-        Returns
-        -------
-        dudt: numpy array of shape(N*n_vars)
+        Returns:
             Time derative at each point of input snapshot.
         """
         input_array = input_array.reshape(self.net.n_vars, -1)
@@ -250,15 +222,14 @@ class Model:
         """
         Integrate idx'th snapshot of dataset for horizon time steps using Euler stepper.
 
-        Arguments:
-        dataset                   - Dataset containing snapshots
-        svd                       - Truncated SVD for regulairzation
-        idx                       - Index of initial snapshot
-        horizon                   - Number of time steps to integrate forward
+        Args:
+            dataset: Dataset containing snapshots
+            svd: Truncated SVD for regulairzation
+            idx: Index of initial snapshot
+            horizon: Number of time steps to integrate forward
 
-        Returns
-        -------
-        Numpy array with integrated data
+        Returns:
+            Numpy array with integrated data
         """
         left_bounds, _, right_bounds, _, _, param = dataset.get_data(True)
         data = []
@@ -293,20 +264,13 @@ class Model:
         """
         Integrate initial condition using the learned model.
 
-        Arguments
-        -------
-        initial_condition: numpy array of shape(N*n_vars)
-            Initial snapshot.
-        pars: list
-            Parameters of the system.
-        t_eval: numpy array
-            Time values at which to return solution.
+        Args:
+            initial_condition:  Initial snapshot.
+            pars: Parameters of the system.
+           t_eval: Time values at which to return solution.
 
-        Returns
-        -------
-        sol.t: numpy array
+        Returns:
             Time values at which the solution was evaluated
-        sol.y numpy array of shape(len(sol.t, n_vars, N))
             Solution obtained from numerical integration.
         """
         print('Integrating using learned PDE.')
